package logic.module1;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import logic.StopWatch;
import logic.module2.CustomIndexer;

import org.apache.log4j.*;
import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;

import com.aliasi.lingmed.parser.*;

public class MedlineParseImplementation implements MedlineHandler {
	
	private Logger log = Logger.getLogger(MedlineParseImplementation.class);
	
	private final String path = "C:\\Users\\Klæboe\\Skole\\MASTER\\MEDLINE\\TEST\\";
	private List<File> queue;
	private File fil;
	private MedlineParser parser;
	private CustomIndexer customIndexer;
	private StopWatch sw;
			
	public MedlineParseImplementation(String pathname) throws IOException {
		log.setLevel(Level.DEBUG);
		sw = new StopWatch();
		System.out.println("Parsing initated!");		
		queue = new ArrayList<File>();
		fil = new File(path);
		customIndexer = new CustomIndexer("MEDLINE_index");		
		
		sw.start();
		System.out.println("Importing files...");
		this.queueFiles(fil);
		parser = new MedlineParser(this, true);
		
		for(File f : queue) {
			System.out.println("Using File: " + f.getName());
			parser.parse(f);
		}
		
		customIndexer.optimzeAndClose();
		queue.clear();
		
		sw.stop();
		System.out.println("Completed parsing, used " + sw.getElapsedTime() + "milliseconds");
	}
	
	@Override
	public void handle(MedlineCitation citation) {
		
		String pmid = citation.pmid();
		String title = citation.article().articleTitleText();
		String abstrct = citation.article().abstrct().textWithoutTruncationMarker();
		
		Document doc = new Document();
		doc.add(new Field("PMID", pmid, Field.Store.YES, Field.Index.NOT_ANALYZED, Field.TermVector.NO));
		doc.add(new Field("Title", title, Field.Store.YES, Field.Index.ANALYZED, Field.TermVector.WITH_POSITIONS_OFFSETS));
		if(!abstrct.equals("")) {
			doc.add(new Field("Abstract", abstrct, Field.Store.YES, Field.Index.ANALYZED, Field.TermVector.WITH_POSITIONS_OFFSETS));
		}
		customIndexer.indexDoc(doc);
	}
	
	private void queueFiles(File file) {
		if(file.isDirectory()) {
			for(File f : file.listFiles()) {
				queueFiles(f);
			}
		} else if(file.isFile()) {
			if(file.getName().toLowerCase().endsWith(".xml")) {
				queue.add(file);
			}
		}
	}
	
	public static void main(String[] args) throws IOException {
		new MedlineParseImplementation("");
	}

	@Override
	public void delete(String pmid) {}
}