package logic.module1;

import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
import org.apache.lucene.document.Field.TermVector;
import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;
import org.xml.sax.ext.DefaultHandler2;
import org.xml.sax.helpers.XMLReaderFactory;

import logic.module2.CustomIndexer;

public class PPIKeyWordParser extends DefaultHandler2 {
	
	private static final String KEYWORD_PATH = "C:\\Users\\Klæboe\\Skole\\MASTER\\PPI-DIP\\keywordlist.xml";

	private FileReader reader;
	private CustomIndexer cIndexer;
	private String value;
	private String category;
	
	
	public PPIKeyWordParser(String filePath) {
		super();
		cIndexer = new CustomIndexer("Keyword_index");
		
		try {
			XMLReader xmlReader = XMLReaderFactory.createXMLReader();
			xmlReader.setContentHandler(this);
			xmlReader.setErrorHandler(this);
			
			reader = new FileReader(KEYWORD_PATH);			
			xmlReader.parse(new InputSource(reader));
			
		} catch (SAXException e) {
			
			e.printStackTrace();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		} 
	}
	
	private String getText() {
		return value;
	}
	
	@Override
	public void characters(char[] ch, int start, int length) throws SAXException {
		value = new String(ch, start, length);
	}
	
	@Override
	public void startDocument() throws SAXException {
	}

	@Override
	public void startElement(String uri, String localName, String qName, Attributes attributes) throws SAXException {		
		if ("category".equals(qName)) {
			category = attributes.getValue(0);
		}
	}

	@Override
	public void endDocument() throws SAXException {
		cIndexer.optimzeAndClose();
	}

	@Override
	public void endElement(String uri, String localName, String qName) throws SAXException {
		if("word".equals(qName)) {
			Document doc = new Document();
			doc.add(new Field(category, this.getText(), Field.Store.YES, Field.Index.ANALYZED, TermVector.NO));
			cIndexer.indexDoc(doc);
		}
		
	}
	
	public static void main(String[] args) {
		new PPIKeyWordParser("");
	}
}
