package logic.module1;

import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

import logic.module2.CustomIndexer;

import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;
import org.xml.sax.ext.DefaultHandler2;
import org.xml.sax.helpers.XMLReaderFactory;

public class UniProtXMLparser extends DefaultHandler2 {
	
	private final String sprotXMLPath = "C:\\Users\\Klæboe\\Skole\\MASTER\\ProteinDatabaseUniProtKB-SwissProt\\uniprot_sprot.xml";
	
	private CustomIndexer cIndexer;
	private String value;
	private NonFuncCharRemoval preProcesser;
	private boolean recommended, alternative;
	private Document doc;
	
	public UniProtXMLparser(String filePath) {
		super();
		cIndexer = new CustomIndexer("UniProt_index");
		preProcesser = new NonFuncCharRemoval();
		recommended = alternative = false;
		
		try {
			XMLReader xmlReader = XMLReaderFactory.createXMLReader();
			xmlReader.setContentHandler(this);
			xmlReader.setErrorHandler(this);
			
			FileReader fReader = new FileReader(sprotXMLPath);
			xmlReader.parse(new InputSource(fReader));
			
//			FileReader fReader2 = new FileReader(trmblXMLPath);
//			xmlReader.parse(new InputSource(fReader2));
			
			cIndexer.optimzeAndClose();
			
		} catch (SAXException e) {
			e.printStackTrace();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	private String getText() {		
		return value;
	}

	@Override
	public void characters(char[] ch, int start, int length) throws SAXException {
		value = new String(ch, start, length);
	}
		
	@Override
	public void endElement(String uri, String localName, String qName) throws SAXException {		
		if (recommended) {			
			if (qName.equals("fullName")) {				
				doc.add(new Field("RecFullProteinName", this.getText().toLowerCase(), Field.Store.YES,	Field.Index.NOT_ANALYZED, Field.TermVector.NO));
				doc.add(new Field("RecPartOfProteinName", preProcesser.preProcessInit(this.getText()), Field.Store.YES, Field.Index.ANALYZED, Field.TermVector.YES));
				
			} else if(qName.equals("shortName")) {
				doc.add(new Field("RecShortName", this.getText().toLowerCase(), Field.Store.YES, Field.Index.NOT_ANALYZED, Field.TermVector.YES));
				doc.add(new Field("RecPartOfShortName", preProcesser.preProcessInit(this.getText()), Field.Store.YES, Field.Index.ANALYZED, Field.TermVector.YES));
			}
			
		} else if(alternative) {
			if (qName.equals("fullName")) {				
				doc.add(new Field("AltFullProteinName", this.getText().toLowerCase(), Field.Store.YES,	Field.Index.NOT_ANALYZED, Field.TermVector.NO));
				doc.add(new Field("AltPartOfProteinName", preProcesser.preProcessInit(this.getText()), Field.Store.YES, Field.Index.ANALYZED, Field.TermVector.YES));
				
			} else if(qName.equals("shortName")) {
				doc.add(new Field("AltShortName", this.getText().toLowerCase(), Field.Store.YES, Field.Index.NOT_ANALYZED, Field.TermVector.YES));
				doc.add(new Field("AltPartOfShortName", preProcesser.preProcessInit(this.getText()), Field.Store.YES, Field.Index.ANALYZED, Field.TermVector.YES));
			}
		}
		
		if(qName.equals("recommendedName")) {
			recommended = false;
		} else if (qName.equals("alternativeName")) {
			alternative = false;
		} else if (qName.equals("protein")) {
			cIndexer.indexDoc(doc);
		}
	}

	@Override
	public void startElement(String uri, String localName, String qName, Attributes attributes) throws SAXException {	 	
		if(qName.equals("protein")) {
			doc = new Document();
		} else if(qName.equals("recommendedName")) {
			recommended = true;
		} else if (qName.equals("alternativeName")) {
			alternative = true;
		}
	}

	@Override
	public void endDocument() throws SAXException {
		
	}	
	
	public static void main(String[] args) {
		new UniProtXMLparser("");
	}
}
