package logic.module2;

import java.io.File;
import java.io.IOException;


import org.apache.lucene.analysis.Analyzer;
import org.apache.lucene.document.Document;
import org.apache.lucene.index.CorruptIndexException;
import org.apache.lucene.index.IndexWriter;
import org.apache.lucene.index.IndexWriter.MaxFieldLength;
import org.apache.lucene.store.FSDirectory;
import org.apache.lucene.store.LockObtainFailedException;

public class CustomIndexer {
	
	private File indexDirectory;
	private IndexWriter iWriter;
	private Analyzer analyzer;
	
	public CustomIndexer(String indexDir) {
		indexDirectory = new File(indexDir);
		analyzer = CustomAnalyzer.getInstance();
		
		if (indexDirectory.canRead()) {
			
			try {
				iWriter = new IndexWriter(FSDirectory.open(indexDirectory),	analyzer, true, MaxFieldLength.UNLIMITED);
			} catch (CorruptIndexException e) {
				e.printStackTrace();
			} catch (LockObtainFailedException e) {
				e.printStackTrace();
			} catch (IOException e) {
				e.printStackTrace();
			}
		} else { System.out.println("Cant read index directory"); }
	}
	
	public void indexDoc(Document doc) {
		if (indexDirectory.canRead()) {
			try {
				iWriter.addDocument(doc);
			} catch (CorruptIndexException e) {
				e.printStackTrace();
			} catch (IOException e) {
				e.printStackTrace();
			}			
		}
	}
	
	public void optimzeAndClose() {
		try {
			iWriter.optimize();
			iWriter.close();
		} catch (CorruptIndexException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}		
	}
	
	public void commit() {
		try {
			iWriter.commit();
		} catch (CorruptIndexException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
