package testing.biocreative;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import logic.StopWatch;
import logic.module1.NonFuncCharRemoval;
import logic.module2.CustomIndexer;

import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

import org.apache.lucene.document.*;

public class BioCreativeParser {
	
	private static final String testPath = "C:\\Users\\Klæboe\\Skole\\MASTER\\MEDLINE\\TEST\\ias_test_abs.xml";
	private static final String indexPath = "MEDLINE_index";
	
	private File fileOrDir;
	private ArrayList<File> queue;
	private NonFuncCharRemoval nfcr;
	private CustomIndexer index;
	private StopWatch sw;
	
	public BioCreativeParser() {
		sw = new StopWatch();
		fileOrDir = new File(testPath);
		index = new CustomIndexer(indexPath);
		nfcr = new NonFuncCharRemoval();
		queue = new ArrayList<File>();		
		System.out.println("Fetching and queuing files");
		this.queueFiles(fileOrDir);
		
		try {
			DocumentBuilder docBuilder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
			System.out.println("Parsing initiating...");
			sw.start();
			for (File input : queue) {
				System.out.println("Parsing file: " + input.getName());
				Document doc = docBuilder.parse(input);
							
				NodeList entryList = doc.getElementsByTagName("entry");
					NodeList pmidList = doc.getElementsByTagName("pmid");
					NodeList titleList = doc.getElementsByTagName("title");
					NodeList abstractList = doc.getElementsByTagName("abstract");
				
					
				for(int i = 0; i < entryList.getLength(); i++) {
					Node entry = entryList.item(i);
					Node pmid = pmidList.item(i);
					Node title = titleList.item(i);
					Node abstrct = abstractList.item(i);
					
					org.apache.lucene.document.Document luceneDoc = new org.apache.lucene.document.Document();
										
					if(pmid.getParentNode().isSameNode(entry) && title.getParentNode().isSameNode(entry) && abstrct.getParentNode().isSameNode(entry)) {
						luceneDoc.add(new Field("PMID", pmid.getTextContent().trim(), Field.Store.YES, Field.Index.NOT_ANALYZED, Field.TermVector.NO));
						luceneDoc.add(new Field("Title", nfcr.preProcessInit(title.getTextContent().trim()), Field.Store.YES, Field.Index.ANALYZED, Field.TermVector.WITH_POSITIONS_OFFSETS));
						luceneDoc.add(new Field("Abstract", nfcr.preProcessInit(abstrct.getTextContent().trim()), Field.Store.YES, Field.Index.ANALYZED, Field.TermVector.WITH_POSITIONS_OFFSETS));
						index.indexDoc(luceneDoc);
					}				
				}
			}
			
			index.optimzeAndClose();
			System.out.println("-------------------");
			System.out.println("Parsing complete; used " + sw.getElapsedTime() + " millisecs");
			sw.stop();			
		
		} catch (ParserConfigurationException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (SAXException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
	
	/**
	 * @param file
	 */
	private void queueFiles(File file) {
		if(file.isDirectory()) {
			for(File f : file.listFiles()) {
				queueFiles(f);
			}
		} else if(file.isFile()) {
			if(file.getName().toLowerCase().endsWith(".xml")) {
				queue.add(file);
			}
		}
	}
	
	public static void main(String[] args) {
		new BioCreativeParser();
	}
}
