package testing.ppi;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import logic.StopWatch;
import logic.module1.NonFuncCharRemoval;
import logic.module2.CustomIndexer;

import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

import org.apache.lucene.document.*;

public class PPIEvalParser {
	
	private static final String testPath = "C:\\Users\\Klæboe\\Desktop\\ppi-eval-standard-0.9.2b\\ppi-eval-standard\\test";
	private static final String indexPath = "PPIeval_index";
	
	private File fileOrDir;
	private ArrayList<File> queue;
	private NonFuncCharRemoval nonFuncCharRem;
	private CustomIndexer index;
	private StopWatch sw;
	
	public PPIEvalParser() {
		sw = new StopWatch();
		fileOrDir = new File(testPath);
		index = new CustomIndexer(indexPath);

		queue = new ArrayList<File>();
		nonFuncCharRem = new NonFuncCharRemoval();		
		System.out.println("Fetching and queuing files");
		this.queueFiles(fileOrDir);
		
		try {
			DocumentBuilder docBuilder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
			System.out.println("Parsing initiating...");
			sw.start();
			for (File input : queue) {
				Document doc = docBuilder.parse(input);
							
				NodeList documentList = doc.getElementsByTagName("document");
					NodeList sentenceList = doc.getElementsByTagName("sentence");
						NodeList entityList = doc.getElementsByTagName("entity");
						NodeList pairList = doc.getElementsByTagName("pair");
				
				int j = 0;
				int jk = 0;
				int jkl = 0;
				
				System.out.println(sentenceList.item(sentenceList.getLength()-1).getAttributes().getNamedItem("id"));
				
				for(int i = 0; i < documentList.getLength(); i++) {
					Node docNode = documentList.item(i);					
					org.apache.lucene.document.Document luceneDoc = new org.apache.lucene.document.Document();
					
					while (sentenceList.item(j) != null && sentenceList.item(j).getParentNode().isSameNode(docNode)) {
						
						Node sentenceNode = sentenceList.item(j);
						
						String sentenceID = sentenceNode.getAttributes().getNamedItem("id").getTextContent();
						String sentence = sentenceNode.getAttributes().getNamedItem("text").getTextContent();
						luceneDoc.add(new Field(sentenceID, sentence, Field.Store.YES, Field.Index.ANALYZED, Field.TermVector.WITH_POSITIONS_OFFSETS));
						while (entityList.item(jk) != null && entityList.item(jk).getParentNode().isSameNode(sentenceNode)) {
							
							Node enityNode = entityList.item(jk);
							String entityID = enityNode.getAttributes().getNamedItem("id").getTextContent();
							String offsett = enityNode.getAttributes().getNamedItem("charOffset").getTextContent();
							String type = "Unknown";
							if(enityNode.getAttributes().getNamedItem("type") != null) {
								type = enityNode.getAttributes().getNamedItem("type").getTextContent();
							}
							
							jk++;
							
							luceneDoc.add(new Field(entityID, offsett, Field.Store.YES, Field.Index.ANALYZED, Field.TermVector.NO));							
						}
						
						while(pairList.item(jkl) != null && pairList.item(jkl).getParentNode().isSameNode(sentenceNode)) {
							Node pairNode = pairList.item(jkl);
							String pairID = pairNode.getAttributes().getNamedItem("id").getTextContent();
							String pairTest = pairNode.getAttributes().getNamedItem("e1").getTextContent() + " " + pairNode.getAttributes().getNamedItem("e2").getTextContent();
							
							luceneDoc.add(new Field(pairID, pairTest, Field.Store.YES, Field.Index.ANALYZED, Field.TermVector.NO));
							jkl++;
						}						
						j++;					
					}
					index.indexDoc(luceneDoc);
				}
				System.out.println(input.getName() + " complete; used " + sw.getElapsedTime() + "millisecs");
			}
			
			index.optimzeAndClose();
			System.out.println("-------------------");
			System.out.println("Parsing complete; used " + sw.getElapsedTime() + " millisecs");
			sw.stop();			
		
		} catch (ParserConfigurationException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (SAXException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
	
	/**
	 * @param file
	 */
	private void queueFiles(File file) {
		if(file.isDirectory()) {
			for(File f : file.listFiles()) {
				queueFiles(f);
			}
		} else if(file.isFile()) {
			if(file.getName().toLowerCase().endsWith(".xml")) {
				queue.add(file);
			}
		}
	}
	
	public static void main(String[] args) {
		new PPIEvalParser();
	}
}
