package testing.ppi;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;
import java.util.Map.Entry;

import org.apache.avalon.framework.activity.Suspendable;
import org.apache.lucene.document.Document;
import org.apache.lucene.document.Fieldable;
import org.apache.lucene.index.CorruptIndexException;
import org.apache.lucene.index.IndexReader;
import org.apache.lucene.index.Term;
import org.apache.lucene.index.TermDocs;
import org.apache.lucene.index.TermEnum;
import org.apache.lucene.index.TermFreqVector;
import org.apache.lucene.index.TermPositionVector;
import org.apache.lucene.index.IndexReader.FieldOption;
import org.apache.lucene.queryParser.MultiFieldQueryParser;
import org.apache.lucene.queryParser.ParseException;
import org.apache.lucene.search.IndexSearcher;
import org.apache.lucene.search.PrefixQuery;
import org.apache.lucene.search.Query;
import org.apache.lucene.search.TopDocsCollector;
import org.apache.lucene.search.TopScoreDocCollector;
import org.apache.lucene.search.FieldComparator.DocComparator;
import org.apache.lucene.store.FSDirectory;
import org.apache.lucene.util.Version;

import logic.StopWatch;
import logic.module2.CustomAnalyzer;
import logic.module3.PreQueryProcess;

public class PPIEvalTermCategorizer {
	
	private static final String PPIEVAL_INDEX_PATH = "PPIEval_index";
	private static final String KEYWORD_INDEX_PATH = "Keyword_index";
	private static final String[] KEYWORDARRAY = {"Activate", "Association", "Attach", "Break Bond", "Cause", 
													"Contain", "Create Bond", "Generate", "Inactivate", "Modify",
													"Process", "React", "Release", "Signal", "Substitute"};
	
	private IndexReader evalReader;
	private IndexSearcher keywordSearcher;
	private File ppiEvalDir, keywordDir;
	private Document doc;
	private TermDocs docs;
	private List<Fieldable> fields;
	private ArrayList<Document> documentList;
	private Map<String, TermPositionVector> sentenceIDtoTFV;
	private Map<String, ArrayList<String>> sentenceIDtoKeyword;
	private ArrayList<String> keywordsLocated;
	private int length;
	
	private StopWatch sw;
	
	public PPIEvalTermCategorizer() {
		sw = new StopWatch();
		
		ppiEvalDir = new File(PPIEVAL_INDEX_PATH);
		keywordDir = new File(KEYWORD_INDEX_PATH);
		documentList = new ArrayList<Document>();
		keywordsLocated = new ArrayList<String>();
		sentenceIDtoTFV = new TreeMap<String, TermPositionVector>();
		sentenceIDtoKeyword = new HashMap<String, ArrayList<String>>();
		
		if(ppiEvalDir.canRead() && keywordDir.canRead()) {
			try {
				evalReader = IndexReader.open(FSDirectory.open(ppiEvalDir));
				keywordSearcher = new IndexSearcher(FSDirectory.open(keywordDir));
				docs = evalReader.termDocs();
//				sw.start();
				
				while(docs.next()) {
					int docNumber = docs.doc();
					doc = evalReader.document(docNumber);
					fields = doc.getFields();
					length = fields.get(0).name().length();		
					documentList.add(doc);
					
					for(Fieldable f : fields) {
						if(f.name().contains(".s") && f.name().length() == length) {
							if (this.determinePPIkeywordnumber(doc.get(f.name())) > 0) {								
								sentenceIDtoTFV.put(f.name(), (TermPositionVector)evalReader.getTermFreqVector(docNumber, f.name()));
								sentenceIDtoKeyword.put(f.name(), keywordsLocated);
								keywordsLocated = new ArrayList<String>();
							}
						}
					}					
				} 
			} catch (CorruptIndexException e) {
				e.printStackTrace();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
		new PPIEvaluation(documentList, sentenceIDtoTFV, sentenceIDtoKeyword);
	}
	
	private int determinePPIkeywordnumber(String text) {
		String[] tokens = text.split("\\s");
		int ppi = 0;
		TopScoreDocCollector col;
		Query q = null;		
		
		for(String s : tokens) {
			s = PreQueryProcess.partOfNamePreProcess(s).toLowerCase().trim();
			
			try {				
				if (PreQueryProcess.useableTokenCheck(s)) {
					col = TopScoreDocCollector.create(1, true);
					q = new MultiFieldQueryParser(Version.LUCENE_30, KEYWORDARRAY, CustomAnalyzer.getInstance()).parse(s);
					keywordSearcher.search(q, col);
					
					if(col.getTotalHits() > 0 && !keywordsLocated.contains(s)) {						
						keywordsLocated.add(s);
						ppi++;						
					}
				} else {
					continue;
				}
			} catch (ParseException e) {
				e.printStackTrace();
			} catch (IOException e) {
				e.printStackTrace();
			}		
		}
		return ppi;
	}
	
	public static void main(String[] args) {
		new PPIEvalTermCategorizer();
	}
}