package testing.ppi;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;

import org.apache.lucene.document.Document;
import org.apache.lucene.document.Fieldable;
import org.apache.lucene.index.TermPositionVector;
import org.apache.lucene.index.TermVectorOffsetInfo;

import com.aliasi.corpus.Corpus;

public class PPIEvaluation {
	
	private ArrayList<Document> documentList;
	private String currentSentenceID;
	private String currentEntityID;
	private String offsett;
	private LinkedList<String> entities;
	private LinkedList<String> pair;
	private ArrayList<String> sentenceIDs;
	private Map<String, TermPositionVector> sentenceIDtoTPV;
	private Map<String, String> sentenceIDtoSentence;
	private Map<String, LinkedList<String>> sentenceIDtoPairList;
	private Map<String, ArrayList<String>> sentenceIDtoKeywordList;
	private Map<String, LinkedList<String>> pairIDtoEntityList;
	private Map<String, String> entityIDtoOffsett;
	private Map<String, Integer[]> keywordToPositions;
	private PPIEvalAnswerFile answer;
	private String currentCorp;
	

	
	public PPIEvaluation(ArrayList<Document> list, Map<String, TermPositionVector> map1, Map<String, ArrayList<String>> map2) {
		this.documentList = list;
		this.sentenceIDtoTPV = map1;
		this.sentenceIDtoKeywordList = map2;
		
		sentenceIDs = new ArrayList<String>();
		sentenceIDtoSentence = new TreeMap<String, String>();
		sentenceIDtoPairList = new TreeMap<String, LinkedList<String>>();
		pairIDtoEntityList = new TreeMap<String, LinkedList<String>>();
		entityIDtoOffsett = new TreeMap<String, String>();
		pair = new LinkedList<String>();
		entities = new LinkedList<String>();
		keywordToPositions = new HashMap<String, Integer[]>();
		currentCorp = "";
		answer = new PPIEvalAnswerFile();
		
		this.initEval();
		this.evaluate();
	}
	
	private void initEval() {
		for(Document d : documentList) {
			List<Fieldable> fields = d.getFields();
			int length = fields.get(0).name().length();
			
			for(Fieldable f : fields) {
				String name = f.name();
								
				if(name.contains(".e")) {
					currentEntityID = name;
					offsett = f.stringValue();
					entityIDtoOffsett.put(currentEntityID, offsett);
				} else if(name.contains(".p")) {					
					entities = new LinkedList<String>();
					sentenceIDtoSentence.put(currentSentenceID, d.get(currentSentenceID));				
					pair.add(name);	
					String[] entitySet = f.stringValue().split("\\s");
					entities.add(entitySet[0]);
					entities.add(entitySet[1]);
					pairIDtoEntityList.put(name, entities);						
				} else if(name.contains(".s") && name.length() == length) {
					if(pair.size() > 0 && !sentenceIDs.contains(currentSentenceID)) {
						sentenceIDs.add(currentSentenceID);
						sentenceIDtoPairList.put(currentSentenceID, pair);
						pair = new LinkedList<String>();
					}
					currentSentenceID = name;					
				}			
			}
			if(pair.size() > 0 && !sentenceIDs.contains(currentSentenceID)) {
				sentenceIDs.add(currentSentenceID);
				sentenceIDtoPairList.put(currentSentenceID, pair);
				pair = new LinkedList<String>();
				entities = new LinkedList<String>();
			}			
		}		
	}
	
	private void evaluate() {
		for(String sentenceID : sentenceIDs) {
			TermPositionVector tfv = sentenceIDtoTPV.get(sentenceID);
			ArrayList<String> a = sentenceIDtoKeywordList.get(sentenceID);
			LinkedList<String> pairIDlist = sentenceIDtoPairList.get(sentenceID);
			boolean interactionOccurs = false;
			String[] nameSplit = sentenceID.split("\\.");
			String corpName = nameSplit[0];
			System.out.println(sentenceID);
			
			if(!currentCorp.equals(corpName)) {
				answer.writerClose();
				answer = new PPIEvalAnswerFile(corpName);
				currentCorp = corpName;
			}

			if (a != null) {
				String[] keywordlist = (String[]) a.toArray(new String[a.size()]);
				for(String s : pairIDlist) {
					String[] entityOffset1 = entityIDtoOffsett.get(pairIDtoEntityList.get(s).get(0)).split("-");
					String[] entityOffset2 = entityIDtoOffsett.get(pairIDtoEntityList.get(s).get(1)).split("-");
				
					for(int i : tfv.indexesOf(keywordlist, 0, keywordlist.length)) {
						TermVectorOffsetInfo[] offsets = tfv.getOffsets(i);
						
						for(TermVectorOffsetInfo tvpoi : offsets) {
							if(this.entityCompare(Integer.parseInt(entityOffset1[0]), tvpoi.getStartOffset(), tvpoi.getEndOffset(), Integer.parseInt(entityOffset2[1]))){
								interactionOccurs = true;
								break;
							} else {
								interactionOccurs = false;
							}
						}
					}
					
					if (interactionOccurs) {
						answer.answerWriter(s, true);
					} else {
						answer.answerWriter(s, false);
					}
				}				
			} else {
				for(String s : pairIDlist) {
					answer.answerWriter(s, false);
				}				
			}
		}
		answer.writerClose();
		System.out.println("Done");
	}
	
	private boolean entityCompare(int endEntity1, int startInteraction, int endInteraction, int startEntity2) {
		
		if(endEntity1 < startInteraction && endInteraction < startEntity2) {
			return true;
		}		
		return false;
	}
}