package testing.yapex;


import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Map;
import java.util.TreeMap;

public class Resultchecker {
	
	private File answerFile;
	private File resultFile;
	private BufferedReader bfAnswerFile, bfResultFile;
	private ArrayList<String> pmidList;
	private ArrayList<String> titleProteins;
	private ArrayList<String> abstractProteins;
	private Map<String, ArrayList<String>> pmidToTitleProteinsANSWER;
	private Map<String, ArrayList<String>> pmidToAbstractProteinsANSWER;
	private Map<String, ArrayList<String>> pmidToTitleProteinsRESULT;
	private Map<String, ArrayList<String>> pmidToAbstractProteinsRESULT;
	private String currentPMID = "";
	private String line;
	private String[] linePieces;
	
	public Resultchecker(String path1, String path2) {
		answerFile = new File(path1);
		resultFile = new File(path2);
		pmidList = new ArrayList<String>();
		titleProteins = new ArrayList<String>();
		abstractProteins = new ArrayList<String>();
		pmidToTitleProteinsANSWER = new TreeMap<String, ArrayList<String>>();
		pmidToAbstractProteinsANSWER = new TreeMap<String, ArrayList<String>>();
		pmidToTitleProteinsRESULT = new TreeMap<String, ArrayList<String>>();
		pmidToAbstractProteinsRESULT = new TreeMap<String, ArrayList<String>>();
		
		this.makeAnswerSet(answerFile);		
		this.makeResultSet(resultFile);
		this.calculateFScore(calculatePrecision(), calculateRecall());
		
	}
	
	private void makeAnswerSet(File f) {
		try {
			bfAnswerFile = new BufferedReader(new FileReader(f));
			
			line = bfAnswerFile.readLine();
				linePieces = line.split(":");
				currentPMID = linePieces[0];
				pmidList.add(currentPMID);			
				titleProteins.add(linePieces[2]);
			line = bfAnswerFile.readLine();
			
			while(line != null) {
				linePieces = line.split(":");
				if(currentPMID.equals(linePieces[0]) && linePieces[1].equals("Title")) {
					titleProteins.add(linePieces[2]);
				} else if(currentPMID.equals(linePieces[0]) && linePieces[1].equals("Abstract")) {
					abstractProteins.add(linePieces[2]);
				} else {
					pmidToTitleProteinsANSWER.put(currentPMID, titleProteins);
					pmidToAbstractProteinsANSWER.put(currentPMID, abstractProteins);
					
					titleProteins = new ArrayList<String>();
					abstractProteins = new ArrayList<String>();
					
					currentPMID = linePieces[0];
					pmidList.add(currentPMID);
					titleProteins.add(linePieces[2]);
				}

				line = bfAnswerFile.readLine();
			}
			pmidToTitleProteinsANSWER.put(currentPMID, titleProteins);
			pmidToAbstractProteinsANSWER.put(currentPMID, abstractProteins);
			
			bfAnswerFile.close();
			
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}		
	}
	
	private void makeResultSet(File f) {
		try {
			bfResultFile = new BufferedReader(new FileReader(f));
			
			line = bfResultFile.readLine();
				linePieces = line.split(":");
				currentPMID = linePieces[0];
				pmidList.add(currentPMID);			
				titleProteins.add(linePieces[2]);
			line = bfResultFile.readLine();
			
			while(line != null) {
				linePieces = line.split(":");
				if(currentPMID.equals(linePieces[0]) && linePieces[1].equals("Title")) {
					titleProteins.add(linePieces[2]);
				} else if(currentPMID.equals(linePieces[0]) && linePieces[1].equals("Abstract")) {
					abstractProteins.add(linePieces[2]);
				} else {
					pmidToTitleProteinsRESULT.put(currentPMID, titleProteins);
					pmidToAbstractProteinsRESULT.put(currentPMID, abstractProteins);
					
					titleProteins = new ArrayList<String>();
					abstractProteins = new ArrayList<String>();
					
					currentPMID = linePieces[0];
					pmidList.add(currentPMID);			
					titleProteins.add(linePieces[2]);
				}

				line = bfResultFile.readLine();
			}
			pmidToTitleProteinsRESULT.put(currentPMID, titleProteins);
			pmidToAbstractProteinsRESULT.put(currentPMID, abstractProteins);

			bfResultFile.close();
			
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}		
	}
	
	private Double calculatePrecision() {
		int retrievedTitleAnswers = 0;
		int retrivedAbstractAnswers = 0;		
		int titleHits = 0;
		int abstractHits = 0;
		
		for(String pmid : pmidList) {
			ArrayList<String> titleProteins = pmidToTitleProteinsANSWER.get(pmid);
			ArrayList<String> absProteins = pmidToAbstractProteinsANSWER.get(pmid);
			
			if (titleProteins != null && absProteins != null) {
				for (String s : pmidToTitleProteinsRESULT.get(pmid)) {
					retrievedTitleAnswers++;
					if (titleProteins.contains(s)) {
						titleHits++;
					}
				}
				for (String s : pmidToAbstractProteinsRESULT.get(pmid)) {
					retrivedAbstractAnswers++;
					if (absProteins.contains(s)) {
						abstractHits++;
					}
				}
			}			
		}
		
		Double prec = (new Double(titleHits + abstractHits) / new Double(retrievedTitleAnswers + retrivedAbstractAnswers));
		
		System.out.println("Returned Titlehits: " + retrievedTitleAnswers);
		System.out.println("Comfirmed Titlehits: " + titleHits);
		System.out.println("Title Precicion: " + (new Double(titleHits) / new Double(retrievedTitleAnswers)));
		System.out.println();
		System.out.println("Returned Abstracthits: " + retrivedAbstractAnswers);
		System.out.println("Comfirmed AbstractHits: " + abstractHits);
		System.out.println("Abstract Precicion: " + (new Double(abstractHits) / new Double(retrivedAbstractAnswers)));
		System.out.println();
		System.out.println("Combined Precicion: " + prec);
		System.out.println();
		
		return prec;
	}
	
	private Double calculateRecall() {
		int titleAnswersSetCount = 0;
		int abstractAnswersSetCount = 0;		
		int titleHits = 0;
		int abstractHits = 0;
		
		for(String pmid : pmidList) {
			ArrayList<String> titleProteins = pmidToTitleProteinsANSWER.get(pmid);
			ArrayList<String> absProteins = pmidToAbstractProteinsANSWER.get(pmid);
			
			if (titleProteins != null && absProteins != null) {
				titleAnswersSetCount += titleProteins.size();
						
				for (String s : pmidToTitleProteinsRESULT.get(pmid)) {
					
					if (titleProteins.contains(s)) {
						titleHits++;
					}
				}
				
				abstractAnswersSetCount += absProteins.size();
				for (String s : pmidToAbstractProteinsRESULT.get(pmid)) {
	
					if (absProteins.contains(s)) {
						abstractHits++;
					}
				}
			}
		}
		
		Double recall = (new Double(titleHits + abstractHits) / new Double(titleAnswersSetCount + abstractAnswersSetCount));
		
		System.out.println("Title relevance Count: " + titleAnswersSetCount);
		System.out.println("Comfirmed Titlehits: " + titleHits);
		System.out.println("Title Recall: " + (new Double(titleHits) / new Double(titleAnswersSetCount)));
		System.out.println();
		System.out.println("Abstract Relevance Count: " + abstractAnswersSetCount);
		System.out.println("Comfirmed AbstractHits: " + abstractHits);
		System.out.println("Abstract Recall: " + (new Double(abstractHits) / new Double(abstractAnswersSetCount)));
		System.out.println();
		System.out.println("Combined Recall: " + recall);
		
		return recall;
	}

	private void calculateFScore(Double prec, Double recall) {
		Double f = ((2 * prec) * (2 * recall)) / (prec + recall);
		System.out.println();
		System.out.println("F-Score: " + f);
	}
	
	public static void main(String[] args) {
		new Resultchecker("C:\\Users\\Klæboe\\Skole\\MASTER\\Master.java\\yapax_answers.txt", "C:\\Users\\Klæboe\\Skole\\MASTER\\Master.java\\yapex_results.txt");
	}
}