package testing.yapex;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.apache.lucene.document.Field;
import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

import logic.module1.NonFuncCharRemoval;
import logic.module2.CustomIndexer;

public class YapexParser {
	
	private static final String FILEPATH = "C:\\Users\\Klæboe\\Skole\\MASTER\\yapex_text_collection\\";
	private static final String INDEX = "MEDLINE_index";
	
	private File fileOrDir;
	private ArrayList<File> fileQueue;
	private NonFuncCharRemoval nfcr;
	private CustomIndexer cIndex;
	
	public YapexParser() {
		fileOrDir = new File(FILEPATH);
		fileQueue = new ArrayList<File>();
		nfcr = new NonFuncCharRemoval();
		cIndex = new CustomIndexer(INDEX);
		
		this.queueFiles(fileOrDir);
		
		try {
			DocumentBuilder docBuilder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
			
			for(File f : fileQueue) {
				Document xmlDoc = docBuilder.parse(f);
				
				NodeList articleList = xmlDoc.getElementsByTagName("PubmedArticle");
					NodeList pmidList = xmlDoc.getElementsByTagName("PMID");
					NodeList titleList = xmlDoc.getElementsByTagName("ArticleTitle");
					NodeList abstractList = xmlDoc.getElementsByTagName("AbstractText");
					
					for(int i = 0; i < articleList.getLength(); i++) {
						Node article = articleList.item(i);
						Node pmid = pmidList.item(i);
						Node title = titleList.item(i);
						Node abstrct = abstractList.item(i);
						
						org.apache.lucene.document.Document luceneDoc = new org.apache.lucene.document.Document();

						if(pmid.getParentNode().isSameNode(article) && title.getParentNode().isSameNode(article) && abstrct.getParentNode().isSameNode(article)) {
							luceneDoc.add(new Field("PMID", pmid.getTextContent(), Field.Store.YES, Field.Index.NOT_ANALYZED, Field.TermVector.NO));
							luceneDoc.add(new Field("Title", nfcr.preProcessInit(title.getTextContent()), Field.Store.YES, Field.Index.ANALYZED, Field.TermVector.WITH_POSITIONS_OFFSETS));
							luceneDoc.add(new Field("Abstract", nfcr.preProcessInit(abstrct.getTextContent()), Field.Store.YES, Field.Index.ANALYZED, Field.TermVector.WITH_POSITIONS_OFFSETS));
							cIndex.indexDoc(luceneDoc);
						}
					}
			}
			
			cIndex.optimzeAndClose();
			
		} catch (ParserConfigurationException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (SAXException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
	
	private void queueFiles(File file) {
		if(file.isDirectory()) {
			for(File f : file.listFiles()) {
				queueFiles(f);
			}
		} else if(file.isFile()) {
			if(file.getName().toLowerCase().endsWith(".xml")) {
				fileQueue.add(file);
			}
		}
	}
	
	public static void main(String[] args) {
		new YapexParser();
	}
}
